@@ -10,3 +10,8 @@ if __name__ == '__main__':
         log = get_logger(__name__)
         log.info('Exiting...')
         exit()
+    except Exception as e:
+        log = get_logger(__name__)
+        log.fatal(e)
+        raise
+        exit(1)
